<?php

namespace Drupal\graphql_directives;

use Drupal\graphql\GraphQL\Execution\FieldContext;

/**
 * A structured API object for GraphQL resolvers.
 */
class Api {

  /**
   * Create a new arguments object.
   *
   * @param mixed $value
   *   The current graphql node value.
   * @param array<string,mixed> $args
   *   Dictionary of additional arguments.
   * @param \Drupal\graphql\GraphQL\Execution\ResolveContext $context
   *   The evaluations resolve context.
   */
  public function __construct(
    /**
     * The current GraphQL parent node value.
     *
     * This is either the current object node, or the output of
     * the previous directive.
     */
    public mixed $parent,
    /**
     * Arguments passed into the directive.
     * Placeholders for node value and arguments are already resolved.
     */
    public array $args,
    /**
     * The current field context to adjust context and cache information.
     */
    public FieldContext $context,
  ) {
  }

}
