<?php

namespace Drupal\graphql_directives;

/**
 * Basic utilities.
 */
class DeprecatedPluginCompatibility {

  /**
   * Pluck the directive input from an argument vector.
   *
   * Will throw due to its return type annotation if arguments are wrong.
   *
   * @param array $argv
   *   The $arguments parameter passed into __call.
   */
  protected function getBuilder(array $argv): DirectiveResolverBuilder {
    return $argv[0];
  }

  /**
   * Run a legacy data producer plugin.
   *
   * Used to retain plugins in the new plugin-less execution strategy.
   *
   * Usage:
   *
   * implementation(drupal): graphql_directives.plugin_compat::data_producer
   *
   * @param string $name
   *   The function name that should match the directive id.
   * @param array $argv
   *   All call arguments. The first one is the Api bag.
   */
  public function __call(string $name, array $argv) : mixed {
    $builder = $this->getBuilder($argv);
    $producer = $builder->produce($name);
    foreach ($builder->arguments() as $key) {
      $producer = $producer->map($key, $builder->fromArgument($key));
    }
    return $producer;
  }

}
