<?php

namespace Drupal\graphql_directives;

use Drupal\graphql\GraphQL\ResolverBuilder;

/**
 * Resolver builder for specific directives.
 *
 * A standard ResolverBuilder, but "fromArgument" will
 * return local directive argument resolvers.
 */
class DirectiveResolverBuilder extends ResolverBuilder {

  /**
   * Constructor.
   *
   * @param string $directive
   *   The directive name.
   * @param array $arguments
   *   Pre-mapped argument resolvers.
   */
  public function __construct(protected string $directive, protected array $arguments) {

  }

  /**
   * Retrieve all argument keys.
   */
  public function arguments() {
    return array_keys($this->arguments);
  }

  /**
   * Adds a query argument value to resolve to.
   */
  public function fromArgument($name) {
    if (array_key_exists($name, $this->arguments)) {
      return $this->arguments[$name];
    }
  }

}
