<?php

namespace Drupal\graphql_directives\Directives;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\Resolver\ResolverInterface;

/**
 * Resolvers related to menus.
 */
class Menus {

  /**
   * Retrieve items from a menu.
   */
  public static function items(ResolverBuilder $builder) : ResolverInterface {
    return $builder->compose(
      $builder->produce('menu_links')
        ->map('menu', $builder->fromParent()),
      $builder->produce('filter_menu_items')
        ->map('items', $builder->fromParent())
        ->map('max_level', $builder->fromArgument('max_level') ?? $builder->fromValue(0))
    );
  }

  /**
   * Retrieve an item's url.
   */
  public static function itemUrl(ResolverBuilder $builder) : ResolverInterface {
    $item = $builder->fromParent();
    return $builder->compose(
      $builder->produce('menu_tree_link')->map('element', $item),
      $builder->produce('menu_link_url')->map('link', $item),
      $builder->produce('url_path')->map('url', $item),
    );
  }

  /**
   * Retrieve an item's parent id.
   */
  public static function parentId(ResolverBuilder $builder) : ResolverInterface {
    return $builder->produce('menu_item_parent_id')
      ->map('item', $builder->fromParent());
  }

  /**
   * Retrieve an item's label.
   */
  public static function itemLabel(ResolverBuilder $builder) : ResolverInterface {
    $item = $builder->fromParent();
    return $builder->compose(
      $builder->produce('menu_tree_link')->map('element', $item),
      $builder->produce('menu_link_label')->map('link', $item),
    );
  }

  /**
   * Retrieve an item's id.
   */
  public static function itemId(ResolverBuilder $builder) : ResolverInterface {
    return $builder->produce('menu_item_id')
      ->map('item', $builder->fromParent());
  }

}
