<?php

namespace Drupal\graphql_directives\Directives;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\Resolver\ResolverInterface;
use Drupal\graphql_directives\Api;
use Symfony\Component\Yaml\Yaml;

/**
 * User-related directive implementations.
 */
class Utilities {

  /**
   * Retrieve a property value from an object.
   */
  public static function prop(ResolverBuilder $builder) : ResolverInterface {
    return $builder->produce('prop')
      ->map('input', $builder->fromParent())
      ->map('property', $builder->fromArgument('key'));
  }

  /**
   * Seek an element in a list.
   */
  public static function seek(ResolverBuilder $builder): ResolverInterface {
    return $builder->produce('seek')
      ->map('input', $builder->fromParent())
      ->map('position', $builder->fromArgument('pos'));
  }

  /**
   * Provide a static value.
   */
  public static function value(Api $api) : mixed {
    foreach (['string', 'int', 'float', 'boolean'] as $key) {
      if (array_key_exists($key, $api->args)) {
        return $api->args[$key];
      }
    }
    if (array_key_exists('json', $api->args)) {
      return json_decode($api->args['json']);
    }
    if (array_key_exists('yaml', $api->args)) {
      return Yaml::parse($api->args['yaml']);
    }
    return NULL;
  }

  /**
   * Resolve a path to an Url object.
   */
  public static function route(ResolverBuilder $builder) : ResolverInterface {
    return $builder->produce('route_load')
      ->map('path', $builder->fromArgument('path'));
  }

  /**
   * Set the context language.
   */
  public static function lang(ResolverBuilder $builder) : ResolverInterface {
    return $builder->tap($builder->produce('language_switch')
      ->map('language', $builder->fromArgument('code') ?? $builder->fromParent()));
  }

}
