<?php

namespace Drupal\graphql_directives\GraphQL\Resolvers;

use Drupal\graphql\GraphQL\Execution\FieldContext;
use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\GraphQL\Resolver\ResolverInterface;
use Drupal\graphql\GraphQL\Utility\DeferredUtility;
use Drupal\graphql_directives\Api;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * Exectute a container or static service method.
 */
class Service implements ResolverInterface {

  /**
   * Construct a Service resolver.
   *
   * @param string|null $service
   *   The symfony service name.
   * @param string|null $class
   *   The fully qualified namespace of a class.
   * @param string $method
   *   The method to be called on that service.
   */
  public function __construct(
    protected $service,
    protected $class,
    protected string $method,
    protected Hashmap $arguments,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public function resolve(
    $parent,
    $resolveArguments,
    ResolveContext $context,
    ResolveInfo $info,
    FieldContext $field,
  ) {
    return DeferredUtility::returnFinally(
      $this->arguments,
      function ($args) use (
        $parent,
        $field,
        $context,
        $info,
        $resolveArguments
      ) {
        $service = $this->service;
        $class = $this->class;
        $method = $this->method;
        $arguments = $args->resolve(
          $parent,
          $resolveArguments,
          $context,
          $info,
          $field
        );
        if ($service) {
          $instance = \Drupal::service($service);
          return $instance->$method(
            new Api($parent, $arguments, $field)
          );
        }
        if ($class) {
          if (!class_exists($class)) {
            throw new \Exception("Class $class does not exist.");
          }
          return $class::$method(
            new Api($parent, $arguments, $field)
          );
        }
      });
  }

}
