<?php

namespace Drupal\graphql_directives;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\Resolver\ResolverInterface;

/**
 * Exception thrown if a directive implementation does not match the interface.
 */
class MethodInterfaceException extends \Exception {

  public function __construct(protected $class, protected $method) {
    $apiclass = Api::class;
    $resolverbuilderclass = ResolverBuilder::class;
    $resolverinterfaceclass = ResolverInterface::class;
    parent::__construct(implode("\n", [
      "Invalid directive implementation method {$this->class}::{$this->method}.",
      "It should ...",
      "- ... either accept a single input argument of type {$apiclass} and a declared return type.",
      "- ... or accept a single input argument of type {$resolverbuilderclass} and {$resolverinterfaceclass} as return type.",
    ]));
  }

}
