<?php

namespace Drupal\graphql_directives_test;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\Resolver\ResolverInterface;
use Drupal\graphql_directives\Api;

/**
 * Test resolvers.
 *
 * Service class for providing static and container injected resolvers.
 */
class TestResolvers {

  protected string $value;

  /**
   * @param string $value
   */
  public function __construct($value) {
    $this->value = $value;
  }

  /**
   * A static reslver.
   */
  public static function staticValue() : string {
    return 'static value';
  }

  /**
   * A resolver, acessing a container injected value.
   */
  public function containerValue() : string {
    return $this->value;
  }

  /**
   * A service method using the builder pattern.
   */
  public static function legacy(ResolverBuilder $builder): ResolverInterface {
    return $builder->fromValue('legacy');
  }

  /**
   * A static function that does not conform to the interface.
   */
  public function wrongArgumentType(string $input): string {
    return $input;
  }

  /**
   * A service method without output declaration.
   */
  public function missingReturnType(Api $api) {
    return $api->args['input'];
  }

  /**
   * A legacy service method with a wrong return type.
   */
  public function legacyWrongReturnType(ResolverBuilder $builder): string {
    return 'test';
  }

}
