<?php

namespace Drupal\Tests\graphql_directives\Kernel;

use Drupal\Tests\graphql\Kernel\GraphQLTestBase;
use Drupal\Tests\graphql_directives\Traits\GraphQLDirectivesTestTrait;

/**
 * Kernel test case for autoloaded directives.
 *
 * Verifies that implementations are picked based on context precedence.
 */
class AutoloadTest extends GraphQLTestBase {
  use GraphQLDirectivesTestTrait;

  protected static $modules = [
    'graphql_directives',
    'graphql_directives_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() : void {
    parent::setUp();
    $moduleDir = \Drupal::moduleHandler()->getModule('graphql_directives')->getPath();
    $this->setupDirectableSchema($moduleDir . '/tests/assets/autoload');
  }

  /**
   * Test execution of a static class value.
   */
  public function testStaticValue() : void {
    $this->assertResults('{ static }', [], ['static' => 'static value']);
  }

  /**
   * Test execution of a service method value.
   */
  public function testContainerValue() : void {
    $this->assertResults('{ service }', [], ['service' => 'container value']);
  }

  /**
   * Test execution of a not implemented directive.
   */
  public function testMissingImplementation() : void {
    $this->assertResults('{ notImplemented }', [], ['notImplemented' => NULL]);
  }

}
