<?php

namespace Drupal\Tests\graphql_directives\Kernel;

use Drupal\Tests\graphql\Kernel\GraphQLTestBase;
use Drupal\Tests\graphql_directives\Traits\GraphQLDirectivesTestTrait;

/**
 *
 */
class UtilitiesTest extends GraphQLTestBase {
  use GraphQLDirectivesTestTrait;

  protected static $modules = [
    'graphql_directives',
    'graphql_directives_test',
  ];

  /**
   *
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig('graphql_directives');
    $moduleDir = \Drupal::moduleHandler()->getModule('graphql_directives')->getPath();
    $this->setupDirectableSchema($moduleDir . '/tests/assets/utilities', ['test_directable']);
  }

  /**
   *
   */
  public function testSchemaLoading() {
    $this->assertResults('{ foo }', [], ['foo' => 'bar']);
  }

  /**
   *
   */
  public function testValuePrimitives() {
    $this->assertResults('{ primitiveString }', [], ['primitiveString' => 'foo']);
    $this->assertResults('{ primitiveInt }', [], ['primitiveInt' => 42]);
    $this->assertResults('{ primitiveFloat }', [], ['primitiveFloat' => 3.14]);
    $this->assertResults('{ primitiveBoolean }', [], ['primitiveBoolean' => TRUE]);
    $this->assertResults('{ yaml }', [], ['yaml' => ['foo']]);
  }

  /**
   *
   */
  public function testSeekDirective() {
    $this->assertResults('{ seek }', [], ['seek' => 'two']);
  }

  /**
   *
   */
  public function testPropDirective() {
    $this->assertResults('{ prop }', [], ['prop' => 'bar']);
  }

  /**
   *
   */
  public function testMapDirective() {
    $this->assertResults('{ map }', [], ['map' => ['a', 'b']]);
  }

  /**
   *
   */
  public function testUnion() {
    $this->assertResults(
      '{ union { ... on A { y } ... on B { z } } }', [],
      ['union' => [['y' => 'A'], ['z' => 'B']]]
    );
  }

  /**
   *
   */
  public function testInterface() {
    $this->assertResults(
      '{ interface { ... on A { y } ... on B { z } } }', [],
      ['interface' => [['y' => 'A'], ['z' => 'B']]]
    );
  }

  /**
   *
   */
  public function testExtension() {
    $this->assertResults('{ listArticle { title } }', [], [
      'listArticle' => [
        ['title' => 'One'],
        ['title' => 'Two'],
      ],
    ]);
  }

}
